|code_ci| |docs_ci| |coverage| |pypi_version| |license|


Minecraft Interactive World Builder
===================================

.. warning::
    
    UNDER DEVELOPMENT: not all features are yet available and the tutorials 
    are not yet complete.
    
This project is intended as a fun way to learn the Python Programming Language.
It has the following features:

 - Use Python to create anything inside of Minecraft worlds. 
 - Call Python code when events occur inside the world.
 - Use an iPython prompt to interact with the world by typing Python commands
 - Have your player inside the world execute Python code by placing command 
   signs or activating switches/levers with Python actions.

All instructions on how to set up a Minecraft Server and the Python developer
environment are included. There will be a step by step tutorial to
introduce Python Programming.


See `intro` to begin.

============== ==============================================================
PyPI           ``pip install mciwb``
Source code    https://github.com/gilesknap/mciwb
Documentation  https://gilesknap.github.io/mciwb
Releases       https://github.com/gilesknap/mciwb/releases
============== ==============================================================


.. |code_ci| image:: https://github.com/gilesknap/mciwb/workflows/Code%20CI/badge.svg?branch=main
    :target: https://github.com/gilesknap/mciwb/actions?query=workflow%3A%22Code+CI%22
    :alt: Code CI

.. |docs_ci| image:: https://github.com/gilesknap/mciwb/workflows/Docs%20CI/badge.svg?branch=main
    :target: https://github.com/gilesknap/mciwb/actions?query=workflow%3A%22Docs+CI%22
    :alt: Docs CI

.. |coverage| image:: https://codecov.io/gh/gilesknap/mciwb/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/gilesknap/mciwb
    :alt: Test Coverage

.. |pypi_version| image:: https://img.shields.io/pypi/v/mciwb.svg
    :target: https://pypi.org/project/mciwb
    :alt: Latest PyPI version

.. |license| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
    :target: https://opensource.org/licenses/Apache-2.0
    :alt: Apache License

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst
